==> char-info-0.1.4.tgz: package/src/defs/scripts.ts <==
/** @module char-info/defs
 * */ /** */
export module UnicodeScript {
    export const Arabic = "Arabic";
    export const Armenian = "Armenian";
    export const Balinese = "Balinese";
    export const Bamum = "Bamum";
    export const Batak = "Batak";
    export const Bengali = "Bengali";
    export const Bopomofo = "Bopomofo";
    export const Braille = "Braille";
    export const Buginese = "Buginese";
    export const Buhid = "Buhid";
    export const CanadianAboriginal = "CanadianAboriginal";
    export const Cham = "Cham";
    export const Cherokee = "Cherokee";
    export const Common = "Common";
    export const Coptic = "Coptic";
    export const Cyrillic = "Cyrillic";
    export const Devanagari = "Devanagari";
    export const Ethiopic = "Ethiopic";
    export const Georgian = "Georgian";
    export const Glagolitic = "Glagolitic";
    export const Greek = "Greek";
    export const Gujarati = "Gujarati";
    export const Gurmukhi = "Gurmukhi";
    export const Han = "Han";
    export const Hangul = "Hangul";
    export const Hanunoo = "Hanunoo";
    export const Hebrew = "Hebrew";
    export const Hiragana = "Hiragana";
    export const Inherited = "Inherited";
    export const Javanese = "Javanese";    export const Kannada = "Kannada";
    export const Katakana = "Katakana";
    export const KayahLi = "KayahLi";
    export const Khmer = "Khmer";
    export const Lao = "Lao";
    export const Latin = "Latin";
    export const Lepcha = "Lepcha";
    export const Limbu = "Limbu";
    export const Lisu = "Lisu";
    export const Malayalam = "Malayalam";
    export const Mandaic = "Mandaic";
    export const MeeteiMayek = "MeeteiMayek";
    export const Mongolian = "Mongolian";
    export const Myanmar = "Myanmar";
    export const NewTaiLue = "NewTaiLue";
    export const Nko = "Nko";
    export const Ogham = "Ogham";
    export const OlChiki = "OlChiki";
    export const Oriya = "Oriya";
    export const PhagsPa = "PhagsPa";
    export const Rejang = "Rejang";
    export const Runic = "Runic";
    export const Samaritan = "Samaritan";
    export const Saurashtra = "Saurashtra";
    export const Sinhala = "Sinhala";
    export const Sundanese = "Sundanese";
    export const SylotiNagri = "SylotiNagri";
    export const Syriac = "Syriac";
    export const Tagalog = "Tagalog";
    export const Tagbanwa = "Tagbanwa";
    export const TaiLe = "TaiLe";
    export const TaiTham = "TaiTham";
    export const TaiViet = "TaiViet";
    export const Tamil = "Tamil";
    export const Telugu = "Telugu";
    export const Thaana = "Thaana";
    export const Thai = "Thai";
    export const Tibetan = "Tibetan";
    export const Tifinagh = "Tifinagh";
    export const Vai = "Vai";
    export const Yi = "Yi";
}

==> char-info-0.2.2.tgz: package/src/defs/scripts.ts <==
/** @module char-info/defs
 * */
/** */
export module UnicodeScript {
    export const Arabic = "Arabic";
    export const Armenian = "Armenian";
    export const Balinese = "Balinese";
    export const Bamum = "Bamum";
    export const Batak = "Batak";
    export const Bengali = "Bengali";
    export const Bopomofo = "Bopomofo";
    export const Braille = "Braille";
    export const Buginese = "Buginese";
    export const Buhid = "Buhid";
    export const CanadianAboriginal = "CanadianAboriginal";
    export const Cham = "Cham";
    export const Cherokee = "Cherokee";
    export const Common = "Common";
    export const Coptic = "Coptic";
    export const Cyrillic = "Cyrillic";
    export const Devanagari = "Devanagari";
    export const Ethiopic = "Ethiopic";
    export const Georgian = "Georgian";
    export const Glagolitic = "Glagolitic";
    export const Greek = "Greek";
    export const Gujarati = "Gujarati";
    export const Gurmukhi = "Gurmukhi";
    export const Han = "Han";
    export const Hangul = "Hangul";
    export const Hanunoo = "Hanunoo";
    export const Hebrew = "Hebrew";
    export const Hiragana = "Hiragana";
    export const Inherited = "Inherited";
    export const Javanese = "Javanese";
    export const Kannada = "Kannada";
    export const Katakana = "Katakana";
    export const KayahLi = "KayahLi";
    export const Khmer = "Khmer";
    export const Lao = "Lao";
    export const Latin = "Latin";
    export const Lepcha = "Lepcha";
    export const Limbu = "Limbu";
    export const Lisu = "Lisu";
    export const Malayalam = "Malayalam";
    export const Mandaic = "Mandaic";
    export const MeeteiMayek = "MeeteiMayek";
    export const Mongolian = "Mongolian";
    export const Myanmar = "Myanmar";
    export const NewTaiLue = "NewTaiLue";
    export const Nko = "Nko";
    export const Ogham = "Ogham";
    export const OlChiki = "OlChiki";
    export const Oriya = "Oriya";
    export const PhagsPa = "PhagsPa";
    export const Rejang = "Rejang";
    export const Runic = "Runic";
    export const Samaritan = "Samaritan";
    export const Saurashtra = "Saurashtra";
    export const Sinhala = "Sinhala";
    export const Sundanese = "Sundanese";
    export const SylotiNagri = "SylotiNagri";
    export const Syriac = "Syriac";
    export const Tagalog = "Tagalog";
    export const Tagbanwa = "Tagbanwa";
    export const TaiLe = "TaiLe";
    export const TaiTham = "TaiTham";
    export const TaiViet = "TaiViet";
    export const Tamil = "Tamil";
    export const Telugu = "Telugu";
    export const Thaana = "Thaana";
    export const Thai = "Thai";
    export const Tibetan = "Tibetan";
    export const Tifinagh = "Tifinagh";
    export const Vai = "Vai";
    export const Yi = "Yi";
}
